##  AI Risk Associated with AI Agents
If you’re using the [AI Agent Hub](https://help.sap.com/docs/leanix/ea/ai-agent-hub?locale=en-US&state=PRODUCTION&version=CLOUD "Discover and manage AI agents across the organization."), you can assess AI risks for AI agents with the predefined AI risk report. You can find this report in the AI Agents collection on the reports page.
**Note**
If you activated both the [AI agent](https://help.sap.com/docs/leanix/ea/ai-agent-extension-to-meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Activate an optional meta model extension to model and govern your organization’s AI agents and MCP servers.") and the [AI governance](https://help.sap.com/docs/leanix/ea/meta-model-ai-governance-extension?locale=en-US&state=PRODUCTION&version=CLOUD "Improve AI governance and adoption in your organization. Track and manage AI usage, evaluate risks, and assess AI potential.") extensions to the meta model, you can apply a filter for the AI potential of business capabilities. For example, you can start by analyzing AI risks in AI agents related to business capabilities with the highest AI potential. This helps you prioritize areas for risk mitigation initiatives.
To analyze risks associated with AI agents, proceed as follows:
  * Assess AI risk: Apply filters to prioritize unacceptable risks or focus on low-risk areas to guide safe AI adoption and onboarding.
  * Cross-reference AI risk with usage: Use filters for AI risk and apply the Usage view. AI agents with high risk and active usage need immediate attention to mitigate risks.


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiobb46a3f9039246308d12f6f66431223e_LowRes.png)
AI Risk Report for AI Agents
